var Interactive = function ($) {
  /**
   * ------------------------------------------------------------------------
   * Constants
   * ------------------------------------------------------------------------
   */
  // const NAME = 'interactive'
  // const VERSION = '4.0.0'
  var DATA_KEY = 'tdu.interactive';
  var EVENT_KEY = "." + DATA_KEY;
  var Events = {
    TAP: "tap" + EVENT_KEY,
    PRESS: "press" + EVENT_KEY,
    ACTIVE: 'mousedown touchstart',
    DEACTIVE: 'mouseup mouseout touchend touchcancel'
  };
  var ClassName = {
    FOCUS: 'focus',
    INTERACTIVE: 'interactive'
  };
  var Selector = {
    INTERACTIVE: '.interactive',
    FOCUS: '.click'
  };
  var Interval = {
    MIN_TRANSITION: 150,
    LONG_PRESS: 1000
    /**
     * ------------------------------------------------------------------------
     * Api Definition
     * ------------------------------------------------------------------------
     */

  };
  $(document).on(Events.ACTIVE, Selector.INTERACTIVE, function (event) {
    var _this = this;

    var startTime = Date.now();
    this.classList.add(ClassName.FOCUS);

    if (this.$previousHandler) {
      clearTimeout(this.$previousHandler);
      this.$previousHandler = 0;
    }

    var releaseHandler = function releaseHandler() {
      // Clear long press timer
      _this.$longPressHandler = 0;
      _this.$longPressTriggered = true;
      var delta = Date.now() - startTime;

      if (delta < Interval.MIN_TRANSITION) {
        // If delta is too short, delay transition.
        _this.$previousHandler = setTimeout(function () {
          _this.classList.remove(ClassName.FOCUS);

          $(_this).off(Events.DEACTIVE, releaseHandler);
          _this.$previousHandler = 0;
        }, Interval.MIN_TRANSITION - delta);
      } else {
        // If delta is enough, delay
        _this.classList.remove(ClassName.FOCUS);

        $(_this).off(Events.DEACTIVE, releaseHandler);

        if (delta >= Interval.LONG_PRESS) {
          event.preventDefault();
          event.stopPropagation();
        }
      }
    };

    $(this).trigger($.Event(Events.TAP)); // Add release mouse/touch handler

    $(this).on(Events.DEACTIVE, releaseHandler); // Add long-press handler

    this.$longPressTriggered = true;
    this.$longPressHandler = setTimeout(function () {
      $(_this).trigger($.Event(Events.PRESS));
      _this.$longPressHandler = 0;
    }, Interval.LONG_PRESS);
  });
}($);
//# sourceMappingURL=interactive.js.map